@@ -1,25 +1,25 @@
-from .build_queue import BuildQueueWidget
-from .executor_status import ExecutorStatusWidget
-from .info import InfoWidget
 from .button import ButtonWidget
-from .scroll_bar import ScrollBarWidget
-from .job_details import JobDetailsWidget
-from .text_input_field import TextInputFieldWidget
-from .single_stat import SingleStatWidget
+from .executor_status import ExecutorStatusWidget
 from .figlet_text_widget import FigletTextWidget
-from .flash import FlashWidget, ShowFlashNotification, FlashMessageType
+from .flash import FlashMessageType, FlashWidget, ShowFlashNotification
+from .help import HelpWidget
+from .job_details import JobDetailsWidget
+from .nav import NavWidget
+from .scroll_bar import ScrollBarWidget
+from .text import TextWidget
+from .text_input_field import TextInputFieldWidget
 
 __all__ = (
-    "BuildQueueWidget",
     "ExecutorStatusWidget",
-    "InfoWidget",
     "ScrollBarWidget",
     "ButtonWidget",
     "JobDetailsWidget",
     "TextInputFieldWidget",
-    "SingleStatWidget",
     "FigletTextWidget",
     "FlashWidget",
     "ShowFlashNotification",
     "FlashMessageType",
+    "TextWidget",
+    "NavWidget",
+    "HelpWidget",
 )
